@@ -82,7 +82,7 @@ def get_common_data(user_uuid):
         'is_cdn':is_cdn,
         'usage_limit_b':user.monthly_usage_limit_GB*1024*1024*1024,
         'usage_current_b':user.current_usage_GB*1024*1024*1024,
-        'expire_s':(user.expiry_time-datetime.date(1970, 1, 1)).total_seconds,
+        'expire_s':(user.expiry_time-datetime.date(1970, 1, 1)).total_seconds(),
         'expire_days':(user.expiry_time-datetime.date.today()).days,
         'hconfigs':get_hconfigs(),
         'hdomains':get_hdomains(),
